#line 1 "gabc/gabc-score-determination-l.c"

#line 3 "gabc/gabc-score-determination-l.c"

#define  YY_INT_ALIGNED long int

/* A lexical scanner generated by flex */

#define yy_create_buffer gabc_score_determination__create_buffer
#define yy_delete_buffer gabc_score_determination__delete_buffer
#define yy_scan_buffer gabc_score_determination__scan_buffer
#define yy_scan_string gabc_score_determination__scan_string
#define yy_scan_bytes gabc_score_determination__scan_bytes
#define yy_init_buffer gabc_score_determination__init_buffer
#define yy_flush_buffer gabc_score_determination__flush_buffer
#define yy_load_buffer_state gabc_score_determination__load_buffer_state
#define yy_switch_to_buffer gabc_score_determination__switch_to_buffer
#define yypush_buffer_state gabc_score_determination_push_buffer_state
#define yypop_buffer_state gabc_score_determination_pop_buffer_state
#define yyensure_buffer_stack gabc_score_determination_ensure_buffer_stack
#define yy_flex_debug gabc_score_determination__flex_debug
#define yyin gabc_score_determination_in
#define yyleng gabc_score_determination_leng
#define yylex gabc_score_determination_lex
#define yylineno gabc_score_determination_lineno
#define yyout gabc_score_determination_out
#define yyrestart gabc_score_determination_restart
#define yytext gabc_score_determination_text
#define yywrap gabc_score_determination_wrap
#define yyalloc gabc_score_determination_alloc
#define yyrealloc gabc_score_determination_realloc
#define yyfree gabc_score_determination_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define gabc_score_determination__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer gabc_score_determination__create_buffer
#endif

#ifdef yy_delete_buffer
#define gabc_score_determination__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer gabc_score_determination__delete_buffer
#endif

#ifdef yy_scan_buffer
#define gabc_score_determination__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer gabc_score_determination__scan_buffer
#endif

#ifdef yy_scan_string
#define gabc_score_determination__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string gabc_score_determination__scan_string
#endif

#ifdef yy_scan_bytes
#define gabc_score_determination__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes gabc_score_determination__scan_bytes
#endif

#ifdef yy_init_buffer
#define gabc_score_determination__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer gabc_score_determination__init_buffer
#endif

#ifdef yy_flush_buffer
#define gabc_score_determination__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer gabc_score_determination__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define gabc_score_determination__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state gabc_score_determination__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define gabc_score_determination__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer gabc_score_determination__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define gabc_score_determination_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state gabc_score_determination_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define gabc_score_determination_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state gabc_score_determination_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define gabc_score_determination_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack gabc_score_determination_ensure_buffer_stack
#endif

#ifdef yylex
#define gabc_score_determination_lex_ALREADY_DEFINED
#else
#define yylex gabc_score_determination_lex
#endif

#ifdef yyrestart
#define gabc_score_determination_restart_ALREADY_DEFINED
#else
#define yyrestart gabc_score_determination_restart
#endif

#ifdef yylex_init
#define gabc_score_determination_lex_init_ALREADY_DEFINED
#else
#define yylex_init gabc_score_determination_lex_init
#endif

#ifdef yylex_init_extra
#define gabc_score_determination_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra gabc_score_determination_lex_init_extra
#endif

#ifdef yylex_destroy
#define gabc_score_determination_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy gabc_score_determination_lex_destroy
#endif

#ifdef yyget_debug
#define gabc_score_determination_get_debug_ALREADY_DEFINED
#else
#define yyget_debug gabc_score_determination_get_debug
#endif

#ifdef yyset_debug
#define gabc_score_determination_set_debug_ALREADY_DEFINED
#else
#define yyset_debug gabc_score_determination_set_debug
#endif

#ifdef yyget_extra
#define gabc_score_determination_get_extra_ALREADY_DEFINED
#else
#define yyget_extra gabc_score_determination_get_extra
#endif

#ifdef yyset_extra
#define gabc_score_determination_set_extra_ALREADY_DEFINED
#else
#define yyset_extra gabc_score_determination_set_extra
#endif

#ifdef yyget_in
#define gabc_score_determination_get_in_ALREADY_DEFINED
#else
#define yyget_in gabc_score_determination_get_in
#endif

#ifdef yyset_in
#define gabc_score_determination_set_in_ALREADY_DEFINED
#else
#define yyset_in gabc_score_determination_set_in
#endif

#ifdef yyget_out
#define gabc_score_determination_get_out_ALREADY_DEFINED
#else
#define yyget_out gabc_score_determination_get_out
#endif

#ifdef yyset_out
#define gabc_score_determination_set_out_ALREADY_DEFINED
#else
#define yyset_out gabc_score_determination_set_out
#endif

#ifdef yyget_leng
#define gabc_score_determination_get_leng_ALREADY_DEFINED
#else
#define yyget_leng gabc_score_determination_get_leng
#endif

#ifdef yyget_text
#define gabc_score_determination_get_text_ALREADY_DEFINED
#else
#define yyget_text gabc_score_determination_get_text
#endif

#ifdef yyget_lineno
#define gabc_score_determination_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno gabc_score_determination_get_lineno
#endif

#ifdef yyset_lineno
#define gabc_score_determination_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno gabc_score_determination_set_lineno
#endif

#ifdef yywrap
#define gabc_score_determination_wrap_ALREADY_DEFINED
#else
#define yywrap gabc_score_determination_wrap
#endif

#ifdef yyalloc
#define gabc_score_determination_alloc_ALREADY_DEFINED
#else
#define yyalloc gabc_score_determination_alloc
#endif

#ifdef yyrealloc
#define gabc_score_determination_realloc_ALREADY_DEFINED
#else
#define yyrealloc gabc_score_determination_realloc
#endif

#ifdef yyfree
#define gabc_score_determination_free_ALREADY_DEFINED
#else
#define yyfree gabc_score_determination_free
#endif

#ifdef yytext
#define gabc_score_determination_text_ALREADY_DEFINED
#else
#define yytext gabc_score_determination_text
#endif

#ifdef yyleng
#define gabc_score_determination_leng_ALREADY_DEFINED
#else
#define yyleng gabc_score_determination_leng
#endif

#ifdef yyin
#define gabc_score_determination_in_ALREADY_DEFINED
#else
#define yyin gabc_score_determination_in
#endif

#ifdef yyout
#define gabc_score_determination_out_ALREADY_DEFINED
#else
#define yyout gabc_score_determination_out
#endif

#ifdef yy_flex_debug
#define gabc_score_determination__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug gabc_score_determination__flex_debug
#endif

#ifdef yylineno
#define gabc_score_determination_lineno_ALREADY_DEFINED
#else
#define yylineno gabc_score_determination_lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define gabc_score_determination_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 77
#define YY_END_OF_BUFFER 78
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int32_t yy_accept[309] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   78,   25,   76,   25,   23,    6,   23,   23,
       23,   23,   23,   23,   23,   23,    2,    2,    3,    3,
        1,    8,    9,   27,   26,   50,   71,   29,   28,   56,
       64,   65,   57,   58,   72,   74,   73,   49,   48,   77,
       77,   55,   56,   52,   51,    5,    4,   56,   77,   69,
       77,   77,   70,    0,    0,   23,    6,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,    2,    1,    8,
        0,    7,    0,   27,   26,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   72,
       75,   49,   48,    0,   55,    0,   52,   51,    5,    4,
        0,   69,   69,   69,    0,    0,   70,    0,   24,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   40,   38,    0,   44,    0,   32,    0,    0,    0,
        0,    0,    0,   53,   63,    0,    0,    0,   23,   23,
        0,   23,   23,   14,   23,   11,   23,   23,   23,   41,
       39,   45,    0,   33,    0,    0,    0,    0,    0,    0,
       61,    0,    0,    0,   68,   67,   42,   46,   34,   36,

        0,   54,    0,   23,   23,   23,    0,   23,    0,    0,
       23,   23,   23,   62,    0,   43,   35,   37,   59,    0,
        0,    0,   68,   47,    0,   23,   18,   10,   23,   23,
       23,   23,   23,   23,    0,    0,    0,    0,   30,   60,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   31,
        0,    0,   66,   23,   23,   19,   23,   23,   23,    0,
       23,   23,    0,   23,   23,   23,   23,   23,   23,   23,
       23,   17,   23,   23,   23,   21,   23,   23,   23,   23,
       23,   23,   23,   23,   20,   23,   23,   23,   23,   23,
       23,   23,   15,   23,   23,   13,   23,   23,   23,   23,

       23,   12,   16,   23,   23,   23,   22,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    1,    6,    1,    7,    1,    1,    8,
        9,    1,    1,   10,   11,   12,   13,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   15,   16,   17,
        1,   18,    1,    1,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       20,    1,   21,    1,   19,    1,   22,   23,   24,   25,

       26,   27,   28,   29,   30,   19,   19,   31,   32,   33,
       34,   35,   19,   36,   37,   38,   39,   40,   19,   19,
       41,   19,   42,   43,   44,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   45,    1,    1,    1,
       46,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,   47,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[48] =
    {   0,
        1,    1,    2,    2,    1,    1,    3,    3,    4,    3,
        5,    3,    1,    6,    3,    7,    8,    1,    6,    3,
        3,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    9,    4,    9,    1,    1,    1
    } ;

static const flex_int32_t yy_base[326] =
    {   0,
        0,   45,  707,  706,   90,  132,   41,   44,   71,   78,
      704,  703,   51,   53,   55,   57,  702,  701,   50,   51,
       65,  152,  717,  724,  724,  709,  704,  709,   75,   78,
       55,   74,   65,  101,   92,  107,   68,   76,  724,  706,
       79,    0,  156,    0,  164,  724,  724,  724,  724,  175,
      699,  724,  724,  724,    0,  179,  724,    0,  187,  698,
      724,    0,  697,    0,  113,    0,  126,  696,  694,  107,
      191,  214,  724,  134,    0,  696,  724,  140,  164,  135,
      200,  152,  139,  210,  176,  192,  209,  221,  182,    0,
      232,  236,  241,    0,  245,  249,  262,  675,  687,  237,

      168,  686,  672,  666,  232,  663,  669,  681,  677,    0,
      255,    0,  259,  660,    0,  656,    0,  262,    0,  266,
      673,  680,  679,  260,  276,  300,  724,  304,  272,  681,
      276,   98,  680,  266,  285,  271,  287,  301,  280,  303,
      304,  659,  671,  670,  298,  669,  655,  661,  646,  652,
      644,  724,  724,  655,  724,  662,  724,  656,  330,  660,
      659,  658,  657,  724,  724,  639,  655,  641,  282,  308,
      639,  659,  310,  658,  657,  656,  312,  314,  317,  724,
      724,  724,  648,  724,  642,  646,  645,  644,  643,  638,
      724,  637,  348,  352,  369,  724,  724,  724,  724,  724,

      633,  724,  604,  319,  347,  315,  615,  353,  335,  595,
      348,  608,  603,  724,  590,  724,  724,  724,  724,  575,
      589,  374,  386,  724,  507,  327,  510,  509,  313,  357,
      351,  335,  369,  371,  495,  487,  497,  391,  724,  724,
      373,  375,  386,  387,  390,  189,  503,  389,  391,  724,
      414,  426,  724,  400,  394,  500,  395,  396,  413,  476,
      402,  409,  443,  422,  414,  425,  427,  429,  432,  430,
      438,  498,  442,  441,  445,  495,  446,  447,  448,  451,
      452,  454,  456,  458,  491,  462,  459,  463,  470,  473,
      449,  475,  272,  478,  479,  260,  482,  483,  484,  485,

      486,  219,  160,  487,  489,  493,  122,  724,  526,  535,
      544,  553,  562,  571,  580,  589,  594,  600,  609,  615,
      624,  631,  640,  649,   67
    } ;

static const flex_int32_t yy_def[326] =
    {   0,
      308,    1,  309,  309,  310,  310,  311,  311,  312,  312,
      313,  313,  314,  314,  315,  315,  313,  313,  316,  316,
      316,  316,  308,  308,  308,  308,  317,  308,  317,  317,
      317,  317,  317,  317,  317,  317,  308,  308,  308,  308,
      308,  318,  308,  319,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  320,  308,  308,  321,  308,  308,
      308,  322,  308,  323,  308,  324,  308,  308,  308,  308,
      308,  308,  308,  308,  325,  317,  308,  317,  317,  317,
      317,  317,  317,  317,  317,  317,  317,  308,  308,  318,
      308,  308,  308,  319,  308,  308,  308,  308,  308,  308,

      308,  308,  308,  308,  308,  308,  308,  308,  308,  320,
      308,  321,  308,  308,  322,  308,  323,  308,  324,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  325,
      317,  317,  317,  317,  317,  317,  317,  317,  317,  317,
      317,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  317,  317,
      325,  317,  317,  317,  317,  317,  317,  317,  317,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,

      308,  308,  308,  317,  317,  325,  325,  317,  325,  325,
      317,  317,  317,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  317,  317,  325,  325,  317,
      325,  325,  325,  317,  325,  325,  308,  308,  308,  308,
      317,  325,  317,  325,  325,  325,  317,  325,  325,  308,
      308,  308,  308,  317,  325,  317,  325,  325,  325,  325,
      325,  325,  308,  317,  325,  325,  325,  325,  325,  325,
      325,  317,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,

      325,  325,  325,  325,  325,  325,  325,    0,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308
    } ;

static const flex_int32_t yy_nxt[772] =
    {   0,
       24,   24,   25,   24,   24,   24,   26,   24,   24,   24,
       24,   24,   24,   27,   28,   24,   24,   24,   27,   24,
       24,   29,   27,   27,   30,   27,   27,   31,   27,   27,
       32,   33,   34,   35,   27,   27,   36,   27,   27,   27,
       27,   24,   24,   24,   24,   24,   24,   37,   38,   56,
       39,   40,   56,   65,   65,   65,   65,   67,   67,   67,
       67,   69,   69,   70,   70,   75,   71,   71,   71,   71,
       88,   88,  130,   59,   59,   75,   81,   72,   88,   88,
       59,   59,   73,   57,   75,   75,   57,   60,   75,   41,
       41,   41,   45,   45,   60,   82,   46,   47,   83,   48,

       49,   48,   75,   80,   48,   48,   50,   78,   75,   51,
       52,   75,   61,   79,   61,  118,  118,   75,  123,   61,
      124,   61,   84,   89,   89,   89,  170,   85,  120,  120,
       86,   53,   75,   54,   45,   45,  129,  129,   46,   47,
       74,   48,   49,   48,   87,   75,   48,   48,   50,   75,
       75,   51,   52,   71,   71,   71,   71,   91,   92,   92,
       91,  133,   75,  136,   72,   95,   95,   95,   95,   73,
       75,   93,  131,   53,   75,   54,   96,   96,   96,   96,
      111,  111,  111,  111,  135,  155,   75,   97,  113,  113,
      113,  113,  125,  125,  125,  125,   98,   99,  100,   75,

      101,  132,   75,  126,  102,  139,  156,  103,  127,  104,
       75,  105,  106,  107,  108,  128,  128,  128,  128,   75,
       75,  259,  134,   88,   88,  140,   89,   89,   89,   75,
      141,  127,  137,   91,   92,   92,   91,   91,   92,   92,
       91,  138,   91,   92,   92,   91,   95,   95,   95,   95,
       96,   96,   96,   96,  153,  160,  111,  111,  111,  111,
      113,  113,  113,  113,  118,  118,  161,  154,  120,  120,
       75,  123,  142,  124,  129,  129,   75,  125,  125,  125,
      125,   75,   75,  104,  143,  144,   75,  145,  126,  172,
       75,  146,   75,  127,  147,   75,  174,   75,  148,  149,

      150,  128,  128,  128,  128,  128,  128,  128,  128,  169,
      175,   75,  173,   75,   75,  182,  177,  127,   75,  204,
       75,  127,   75,   75,   75,   75,  176,   75,  228,   75,
      179,  193,  193,  193,  193,  211,  183,   75,  178,  212,
      226,  205,  194,  213,  195,   75,  242,  196,  208,  193,
      193,  193,  193,  222,  222,  222,  222,   75,   75,  231,
      194,   75,  195,   75,  241,  196,  232,   75,  245,  196,
      223,  223,  223,  223,  230,  222,  222,  222,  222,   75,
      244,   75,  227,   75,  243,   75,  234,  223,  223,  223,
      223,  196,  251,  251,  251,  251,   75,   75,  246,   75,

       75,   75,  254,  252,   75,   75,   75,  247,  253,  255,
       75,  256,   75,  257,  258,  251,  251,  251,  251,   75,
      262,  266,  261,   75,   75,  267,  252,  263,  263,  263,
      263,  253,   75,  264,  265,   75,  270,   75,  268,   75,
       75,  271,   75,  253,  263,  263,  263,  263,   75,  273,
      274,   75,   75,  275,  272,   75,   75,   75,   75,   75,
      253,   75,   75,  279,   75,  276,   75,  277,   75,   75,
      278,  280,   75,   75,  282,  283,  281,  287,  286,  288,
       75,  289,  284,   75,  285,   75,  296,  290,   75,   75,
      291,  292,   75,   75,   75,   75,   75,   75,  293,   75,

      295,   75,  294,   75,  301,   75,  303,  299,   75,  269,
       75,  300,  297,  260,  250,  298,  305,  249,  248,   75,
       75,  302,  306,  304,  240,  307,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       66,   66,   66,   66,   66,   66,   66,   66,   66,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   76,   76,

       90,   90,   90,   90,   90,   90,  239,   90,   90,   94,
      238,  237,   94,  236,   94,  110,  110,  110,  235,  110,
      110,  110,  110,  110,  112,  233,  112,  112,  112,  112,
      112,  115,  115,  115,  115,  115,  115,  115,  229,  115,
      117,  225,  117,  117,  117,  117,  117,  117,  117,  119,
      224,  119,  119,  119,  119,  119,  119,  119,  221,  220,
      219,  218,  217,  216,  215,  214,   75,  210,  209,  207,
      206,  203,  202,  201,  200,  199,  198,  197,  192,  191,
      190,  189,  188,  187,  186,  185,  184,  181,  180,  154,
      171,   75,  122,  122,  168,  167,  166,  165,  164,  163,

      162,  159,  158,  157,  152,  151,   75,  122,  121,  116,
      114,  109,   74,   77,   75,   74,  308,   68,   68,   63,
       63,   43,   43,   23,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308
    } ;

static const flex_int32_t yy_chk[772] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    2,    2,    7,
        2,    2,    8,   13,   13,   14,   14,   15,   15,   16,
       16,   19,   20,   19,   20,   31,   21,   21,   21,   21,
       37,   37,  325,    9,    9,   33,   31,   21,   38,   38,
       10,   10,   21,    7,   32,   29,    8,    9,   30,    2,
        2,    2,    5,    5,   10,   32,    5,    5,   33,    5,

        5,    5,   35,   30,    5,    5,    5,   29,  132,    5,
        5,   34,    9,   29,    9,   65,   65,   36,   70,   10,
       70,   10,   34,   41,   41,   41,  132,   35,   67,   67,
       36,    5,  307,    5,    6,    6,   74,   74,    6,    6,
       74,    6,    6,    6,   36,   80,    6,    6,    6,   83,
       78,    6,    6,   22,   22,   22,   22,   43,   43,   43,
       43,   80,   82,   83,   22,   45,   45,   45,   45,   22,
      303,   43,   78,    6,   79,    6,   50,   50,   50,   50,
       56,   56,   56,   56,   82,  101,   85,   50,   59,   59,
       59,   59,   71,   71,   71,   71,   50,   50,   50,  246,

       50,   79,   86,   71,   50,   85,  101,   50,   71,   50,
       81,   50,   50,   50,   50,   72,   72,   72,   72,   87,
       84,  246,   81,   88,   88,   86,   89,   89,   89,  302,
       87,   72,   84,   91,   91,   91,   91,   92,   92,   92,
       92,   84,   93,   93,   93,   93,   95,   95,   95,   95,
       96,   96,   96,   96,  100,  105,  111,  111,  111,  111,
      113,  113,  113,  113,  118,  118,  105,  100,  120,  120,
      296,  124,   96,  124,  129,  129,  134,  125,  125,  125,
      125,  136,  293,   96,   97,   97,  131,   97,  125,  134,
      139,   97,  169,  125,   97,  135,  136,  137,   97,   97,

       97,  126,  126,  126,  126,  128,  128,  128,  128,  131,
      137,  138,  135,  140,  141,  145,  139,  126,  170,  169,
      173,  128,  177,  229,  178,  206,  138,  179,  206,  204,
      141,  159,  159,  159,  159,  177,  145,  226,  140,  178,
      204,  170,  159,  179,  159,  232,  229,  159,  173,  193,
      193,  193,  193,  194,  194,  194,  194,  205,  211,  209,
      193,  231,  193,  208,  226,  193,  209,  230,  232,  194,
      195,  195,  195,  195,  208,  222,  222,  222,  222,  233,
      231,  234,  205,  241,  230,  242,  211,  223,  223,  223,
      223,  222,  238,  238,  238,  238,  243,  244,  233,  248,

      245,  249,  241,  238,  255,  257,  258,  234,  238,  242,
      254,  243,  261,  244,  245,  251,  251,  251,  251,  262,
      249,  257,  248,  259,  265,  258,  251,  252,  252,  252,
      252,  251,  264,  254,  255,  266,  261,  267,  259,  268,
      270,  262,  269,  252,  263,  263,  263,  263,  271,  265,
      266,  274,  273,  267,  264,  275,  277,  278,  279,  291,
      263,  280,  281,  271,  282,  268,  283,  269,  284,  287,
      270,  273,  286,  288,  275,  277,  274,  281,  280,  282,
      289,  283,  278,  290,  279,  292,  291,  284,  294,  295,
      286,  287,  297,  298,  299,  300,  301,  304,  288,  305,

      290,  285,  289,  306,  298,  276,  300,  295,  272,  260,
      256,  297,  292,  247,  237,  294,  304,  236,  235,  228,
      227,  299,  305,  301,  225,  306,  309,  309,  309,  309,
      309,  309,  309,  309,  309,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  311,  311,  311,  311,  311,  311,
      311,  311,  311,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  313,  313,  313,  313,  313,  313,  313,  313,
      313,  314,  314,  314,  314,  314,  314,  314,  314,  314,
      315,  315,  315,  315,  315,  315,  315,  315,  315,  316,
      316,  316,  316,  316,  316,  316,  316,  316,  317,  317,

      318,  318,  318,  318,  318,  318,  221,  318,  318,  319,
      220,  215,  319,  213,  319,  320,  320,  320,  212,  320,
      320,  320,  320,  320,  321,  210,  321,  321,  321,  321,
      321,  322,  322,  322,  322,  322,  322,  322,  207,  322,
      323,  203,  323,  323,  323,  323,  323,  323,  323,  324,
      201,  324,  324,  324,  324,  324,  324,  324,  192,  190,
      189,  188,  187,  186,  185,  183,  176,  175,  174,  172,
      171,  168,  167,  166,  163,  162,  161,  160,  158,  156,
      154,  151,  150,  149,  148,  147,  146,  144,  143,  142,
      133,  130,  123,  122,  121,  116,  114,  109,  108,  107,

      106,  104,  103,  102,   99,   98,   76,   69,   68,   63,
       60,   51,   40,   28,   27,   26,   23,   18,   17,   12,
       11,    4,    3,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      308
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "gabc/gabc-score-determination.l"
#line 2 "gabc/gabc-score-determination.l"
/*
 * Gregorio is a program that translates gabc files to GregorioTeX
 * This file implements the score lexer.
 *
 * Gregorio score determination in gabc input.
 * Copyright (C) 2006-2019 The Gregorio Project (see CONTRIBUTORS.md)
 *
 * This file is part of Gregorio.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "config.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "struct.h"
#include "messages.h"
#include "bool.h"
#include "support.h"

#include "gabc.h"
#include "gabc-score-determination.h"
#include "gabc-score-determination-y.h"

static bool eof_found = false;

#define START_STYLE(STYLE) \
    if (*styles & SB_ ## STYLE) { \
        gregorio_messagef("gabc_score_determination_lex", VERBOSITY_ERROR, 0, \
                _("style already started: %s"), gabc_score_determination_text); \
    } else { \
        *styles ^= SB_ ## STYLE; \
        return STYLE ## _BEGIN; \
    }

#define END_STYLE(STYLE) \
    if (*styles & SB_ ## STYLE) { \
        *styles ^= SB_ ## STYLE; \
        return STYLE ## _END; \
    } else { \
        gregorio_messagef("gabc_score_determination_lex", VERBOSITY_ERROR, 0, \
                _("style not started: %s"), gabc_score_determination_text); \
    }

#define RETURN_CHARACTERS \
    gabc_score_determination_lval.text = \
            gregorio_strdup(gabc_score_determination_text); \
    return CHARACTERS

#define RETURN_SPACE \
    gabc_score_determination_lval.text = gregorio_strdup(" "); \
    return CHARACTERS

#define YY_NO_INPUT

#define YY_INPUT(buf,result,max_size) \
    if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) { \
        int c = '*'; \
        int n; \
        for (n = 0; n < max_size \
                && (c = getc(gabc_score_determination_in)) != EOF \
                && c != '\n'; ++n ) { \
            buf[n] = (char) c; \
        } \
        if (c == '\n') { \
            buf[n++] = (char) c; \
        } \
        if (c == EOF && ferror(gabc_score_determination_in)) { \
            YY_FATAL_ERROR("input in flex scanner failed"); \
        } \
        result = n; \
    } else { \
        errno=0; \
        while ((result = fread(buf, 1, max_size, gabc_score_determination_in)) \
                == 0 && ferror(gabc_score_determination_in)) { \
            if (errno != EINTR) { \
                YY_FATAL_ERROR("input in flex scanner failed"); \
                break; \
            } \
            errno = 0; \
            clearerr(gabc_score_determination_in); \
        } \
    } \
    gabc_digest(buf, result)

#define YY_USER_ACTION gabc_update_location(&gabc_score_determination_lloc, \
        gabc_score_determination_text, gabc_score_determination_leng);

#line 1079 "gabc/gabc-score-determination-l.c"

/* The expression for attribute below is rather messy because we allow
for (a) single-line values, ending with a semicolon at end of line or a
double semicolon, (b) multi-line values, which end at a double
semicolon. */
#line 1085 "gabc/gabc-score-determination-l.c"

#define INITIAL 0
#define attribute 1
#define score 2
#define notes 3
#define sp 4
#define verb 5
#define comments 6
#define inicomments 7
#define alt 8
#define protrusion_value 9
#define protrusion_end 10

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 136 "gabc/gabc-score-determination.l"

#line 1319 "gabc/gabc-score-determination-l.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 309 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 724 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 137 "gabc/gabc-score-determination.l"
{
        /* BOM written by a lot of windows softwares when they write UTF-8 */
    }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 140 "gabc/gabc-score-determination.l"
{
        /* ignoring empty lines */
    }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 143 "gabc/gabc-score-determination.l"
{
        BEGIN(inicomments);
    }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 146 "gabc/gabc-score-determination.l"
{
        BEGIN(INITIAL);
    }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 149 "gabc/gabc-score-determination.l"
{
        /* ignored */
    }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 152 "gabc/gabc-score-determination.l"
{
        BEGIN(attribute);
        return COLON;
    }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 156 "gabc/gabc-score-determination.l"
{
         BEGIN(INITIAL);
         return SEMICOLON;
    }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 160 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ATTRIBUTE;
    }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 165 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ATTRIBUTE;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 170 "gabc/gabc-score-determination.l"
{
         gabc_score_determination_lval.character = gabc_score_determination_text[5];
         return DEF_MACRO;
    }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 174 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
         return NAME;
    }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 179 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return SCORE_COPYRIGHT;
    }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 184 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return GABC_COPYRIGHT;
    }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 189 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return MODE;
    }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 194 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return MODE_MODIFIER;
    }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 199 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return MODE_DIFFERENTIA;
    }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 204 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ANNOTATION;
    }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 209 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return AUTHOR;
    }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 214 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return LANGUAGE;
    }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 219 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return STAFF_LINES;
    }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 224 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return NABC_LINES;
    }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 229 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ORISCUS_ORIENTATION;
    }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 234 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return OTHER_HEADER;
    }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 239 "gabc/gabc-score-determination.l"
{
       BEGIN(score);
       return END_OF_DEFINITIONS;
    }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 243 "gabc/gabc-score-determination.l"
{
        gregorio_messagef("det_score", VERBOSITY_ERROR, 0,
                _("unrecognized character: \"%c\" in definition part"),
                gabc_score_determination_text[0]);
    }
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 248 "gabc/gabc-score-determination.l"
{
        RETURN_SPACE;
    }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 251 "gabc/gabc-score-determination.l"
{
        RETURN_CHARACTERS;
    }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 254 "gabc/gabc-score-determination.l"
{
        return HYPHEN;
    }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 257 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return PROTRUDING_PUNCTUATION;
    }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 262 "gabc/gabc-score-determination.l"
{
        return NLBA_B;
    }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 265 "gabc/gabc-score-determination.l"
{
        return NLBA_E;
    }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 268 "gabc/gabc-score-determination.l"
{
        START_STYLE(I);
    }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 271 "gabc/gabc-score-determination.l"
{
        END_STYLE(I);
    }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 274 "gabc/gabc-score-determination.l"
{
        START_STYLE(TT);
    }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 277 "gabc/gabc-score-determination.l"
{
        END_STYLE(TT);
    }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 280 "gabc/gabc-score-determination.l"
{
        START_STYLE(UL);
    }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 283 "gabc/gabc-score-determination.l"
{
        END_STYLE(UL);
    }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 286 "gabc/gabc-score-determination.l"
{
        START_STYLE(C);
    }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 289 "gabc/gabc-score-determination.l"
{
        END_STYLE(C);
    }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 292 "gabc/gabc-score-determination.l"
{
        START_STYLE(B);
    }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 295 "gabc/gabc-score-determination.l"
{
        END_STYLE(B);
    }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 298 "gabc/gabc-score-determination.l"
{
        START_STYLE(SC);
    }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 301 "gabc/gabc-score-determination.l"
{
        END_STYLE(SC);
    }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 304 "gabc/gabc-score-determination.l"
{
        START_STYLE(ELISION);
    }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 307 "gabc/gabc-score-determination.l"
{
        END_STYLE(ELISION);
    }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 310 "gabc/gabc-score-determination.l"
{
        BEGIN(sp);
        return SP_BEGIN;
    }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 314 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return SP_END;
    }
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
#line 318 "gabc/gabc-score-determination.l"
{
        RETURN_SPACE;
    }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 321 "gabc/gabc-score-determination.l"
{
        RETURN_CHARACTERS;
    }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 324 "gabc/gabc-score-determination.l"
{
        BEGIN(comments);
    }
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 327 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
    }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 330 "gabc/gabc-score-determination.l"
{
        /* ignored */
    }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 333 "gabc/gabc-score-determination.l"
{
        BEGIN(verb);
        return VERB_BEGIN;
    }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 337 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return VERB_END;
    }
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
#line 341 "gabc/gabc-score-determination.l"
{
        RETURN_CHARACTERS;
    }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 344 "gabc/gabc-score-determination.l"
{
        RETURN_CHARACTERS;
    }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 347 "gabc/gabc-score-determination.l"
{
        return CENTER_BEGIN;
    }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 350 "gabc/gabc-score-determination.l"
{
        return CENTER_END;
    }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 353 "gabc/gabc-score-determination.l"
{
        BEGIN(alt);
        return ALT_BEGIN;
    }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 357 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return ALT_END;
    }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 361 "gabc/gabc-score-determination.l"
{
        return EUOUAE_B;
    }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 364 "gabc/gabc-score-determination.l"
{
        return EUOUAE_E;
    }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 367 "gabc/gabc-score-determination.l"
{
        return TRANSLATION_CENTER_END;
    }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 370 "gabc/gabc-score-determination.l"
{
        return TRANSLATION_BEGIN;
    }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 373 "gabc/gabc-score-determination.l"
{
        return TRANSLATION_END;
    }
	YY_BREAK
case 66:
/* rule 66 can match eol */
YY_RULE_SETUP
#line 376 "gabc/gabc-score-determination.l"
{
        return CLEAR;
    }
	YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
#line 379 "gabc/gabc-score-determination.l"
{
        return PROTRUSION;
    }
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 382 "gabc/gabc-score-determination.l"
{
        BEGIN(protrusion_value);
        return PROTRUSION;
    }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 386 "gabc/gabc-score-determination.l"
{
        BEGIN(protrusion_end);
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return PROTRUSION_VALUE;
    }
	YY_BREAK
case 70:
/* rule 70 can match eol */
YY_RULE_SETUP
#line 392 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return PROTRUSION_END;
    }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 396 "gabc/gabc-score-determination.l"
{
        BEGIN(notes);
        return OPENING_BRACKET;
    }
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 400 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return NOTES;
    }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 405 "gabc/gabc-score-determination.l"
{
        return NABC_CUT;
    }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 408 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return CLOSING_BRACKET;
    }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
#line 412 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return CLOSING_BRACKET_WITH_SPACE;
    }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(attribute):
case YY_STATE_EOF(score):
case YY_STATE_EOF(notes):
case YY_STATE_EOF(sp):
case YY_STATE_EOF(verb):
case YY_STATE_EOF(comments):
case YY_STATE_EOF(inicomments):
case YY_STATE_EOF(alt):
case YY_STATE_EOF(protrusion_value):
case YY_STATE_EOF(protrusion_end):
#line 416 "gabc/gabc-score-determination.l"
{
        if (!eof_found) {
            eof_found = true;
            return END_OF_FILE;
        } else {
            yyterminate();
        }
    }
	YY_BREAK
case 76:
/* rule 76 can match eol */
YY_RULE_SETUP
#line 424 "gabc/gabc-score-determination.l"
{
        gregorio_messagef("gabc_score_determination_lex", VERBOSITY_ERROR, 0,
                _("unrecognized character: \"%c\""),
                gabc_score_determination_text[0]);
    }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 429 "gabc/gabc-score-determination.l"
ECHO;
	YY_BREAK
#line 2007 "gabc/gabc-score-determination-l.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 309 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 309 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 308);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 429 "gabc/gabc-score-determination.l"



